@@ -1,9 +1,8 @@
 package MooseX::Role::Parameterized::Meta::Role::Parameterized;
-BEGIN {
-  $MooseX::Role::Parameterized::Meta::Role::Parameterized::AUTHORITY = 'cpan:SARTAK';
-}
 # ABSTRACT: metaclass for parameterized roles
-$MooseX::Role::Parameterized::Meta::Role::Parameterized::VERSION = '1.07';
+
+our $VERSION = '1.09';
+
 use Moose;
 extends 'Moose::Meta::Role';
 with 'MooseX::Role::Parameterized::Meta::Trait::Parameterized';
@@ -25,7 +24,7 @@ MooseX::Role::Parameterized::Meta::Role::Parameterized - metaclass for parameter
 
 =head1 VERSION
 
-version 1.07
+version 1.09
 
 =head1 DESCRIPTION
 
@@ -33,6 +32,17 @@ This is the metaclass for parameterized roles; that is, parameterizable roles
 with their parameters bound. See
 L<MooseX::Role::Parameterized::Meta::Trait::Parameterized> which has all the guts.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Role-Parameterized>
+(or L<bug-MooseX-Role-Parameterized@rt.cpan.org|mailto:bug-MooseX-Role-Parameterized@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
 Shawn M Moore <code@sartak.org>
